@@ -5,8 +5,12 @@
 window.onload = function () {
   setTimeout(function () {
     var script = document.createElement("script");
-    script.type = "text/javascript";
-    script.src  = "https://c328740.ssl.cf1.rackcdn.com/mathjax/latest/MathJax.js?config=TeX-AMS_HTML";
+    if (location.protocol == 'https:') {
+        scriptbase = "https://c328740.ssl.cf1.rackcdn.com/";
+    } else {
+        scriptbase = "http://cdn.mathjax.org/";
+    }
+    script.src  = scriptbase + "mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML";
     document.getElementsByTagName("body")[0].appendChild(script);
   },1)
-}
\ No newline at end of file
+}
