@@ -2,7 +2,7 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
+    "%d min remaining to read": "Il reste encore %d min. de lecture",
     "Also available in:": "Egalement disponible en:",
     "Archive": "Archives",
     "Categories": "Catégories",
@@ -25,6 +25,7 @@ MESSAGES = {
     "RSS feed": "Flux RSS",
     "Read in English": "Lire en français",
     "Read more": "Lire la suite",
+    "Skip to main content": "Aller au contenu principal",
     "Source": "Source",
     "Tags and Categories": "Étiquettes et catégories",
     "Tags": "Étiquettes",
