@@ -7,7 +7,7 @@ MESSAGES = {
     "Archive": "Archiwum",
     "Categories": "Kategorie",
     "Comments": "Komentarze",
-    "LANGUAGE": "polski",
+    "LANGUAGE": "Polski",
     "Languages:": "Języki:",
     "More posts about %s": "Więcej postów o %s",
     "Newer posts": "Nowsze posty",
@@ -25,9 +25,10 @@ MESSAGES = {
     "RSS feed": "Kanał RSS",
     "Read in English": "Czytaj po polsku",
     "Read more": "Czytaj więcej",
+    "Skip to main content": "Przejdź do treści",
     "Source": "Źródło",
     "Tags and Categories": "Tagi i Kategorie",
-    "Tags": "Tags",
+    "Tags": "Tagi",
     "old posts, page %d": "stare posty, strona %d",
     "page %d": "strona %d",
 }
